API Reference
=============

Core Module
----------

.. automodule:: greenfish.core
   :members:
   :undoc-members:
   :show-inheritance:

Redfish Client
~~~~~~~~~~~~~

.. automodule:: greenfish.core.redfish
   :members:
   :undoc-members:
   :show-inheritance:

IPMI Client
~~~~~~~~~~

.. automodule:: greenfish.core.ipmi
   :members:
   :undoc-members:
   :show-inheritance:

Virtual Media Management
~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: greenfish.core.virtualmedia
   :members:
   :undoc-members:
   :show-inheritance:

Remote Console
~~~~~~~~~~~~

.. automodule:: greenfish.core.remoteconsole
   :members:
   :undoc-members:
   :show-inheritance:

Hardware Monitoring
~~~~~~~~~~~~~~~~

.. automodule:: greenfish.core.hwmonitor
   :members:
   :undoc-members:
   :show-inheritance:

Configuration
-----------

.. automodule:: greenfish.config
   :members:
   :undoc-members:
   :show-inheritance:

Settings
~~~~~~~

.. automodule:: greenfish.config.settings
   :members:
   :undoc-members:
   :show-inheritance:

Connection Profile
~~~~~~~~~~~~~~~~

.. automodule:: greenfish.config.connection_profile
   :members:
   :undoc-members:
   :show-inheritance:

Config Manager
~~~~~~~~~~~~

.. automodule:: greenfish.config.config_manager
   :members:
   :undoc-members:
   :show-inheritance:

UI Module
--------

.. automodule:: greenfish.ui
   :members:
   :undoc-members:
   :show-inheritance:

Widgets
~~~~~~

.. automodule:: greenfish.ui.widgets
   :members:
   :undoc-members:
   :show-inheritance:

Dialogs
~~~~~~

.. automodule:: greenfish.ui.dialogs
   :members:
   :undoc-members:
   :show-inheritance:

Main Window
~~~~~~~~~

.. automodule:: greenfish.ui.main_window
   :members:
   :undoc-members:
   :show-inheritance:

Utilities
--------

.. automodule:: greenfish.utils
   :members:
   :undoc-members:
   :show-inheritance:

Logging
~~~~~~

.. automodule:: greenfish.utils.logger
   :members:
   :undoc-members:
   :show-inheritance:

Exceptions
~~~~~~~~~

.. automodule:: greenfish.utils.exceptions
   :members:
   :undoc-members:
   :show-inheritance:
